aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSander Vrijders <sander.vrijders@ugent.be>2018-08-09 10:39:45 +0200
committerSander Vrijders <sander.vrijders@ugent.be>2018-08-09 10:39:45 +0200
commitcde0463f119173f88a66eb1b4d334469fbcd845b (patch)
tree67bffb97aaad04b92571266207cb8d286c1f4553
parent0ea1646ab448d51edc2bc7802d7b075ed0f3f324 (diff)
downloadrumba-cde0463f119173f88a66eb1b4d334469fbcd845b.tar.gz
rumba-cde0463f119173f88a66eb1b4d334469fbcd845b.zip
storyboard: Rename async to asyn
In Python 3.7, async is a reserved keyword, which caused Rumba to fail since we used async as a function parameter.
-rw-r--r--rumba/storyboard.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/rumba/storyboard.py b/rumba/storyboard.py
index 200cca7..c6da6cb 100644
--- a/rumba/storyboard.py
+++ b/rumba/storyboard.py
@@ -810,7 +810,7 @@ class StoryBoard(_SBEntity):
node=None,
proc_id=None,
callback=None,
- async=True):
+ asyn=True):
"""
Runs the specified client app with the specified parameters.
@@ -828,9 +828,9 @@ class StoryBoard(_SBEntity):
:param callback: callable or list thereof to be run
after client termination
:type callback: `callable` or `list` of `callable`
- :param async: if true, the SSH communication will be dealt
- with asynchronously
- :type async: `bool`
+ :param asyn: if true, the SSH communication will be dealt
+ with asynchronously
+ :type asyn: `bool`
"""
if isinstance(client, str):
client = self.client_apps[client]
@@ -847,7 +847,7 @@ class StoryBoard(_SBEntity):
callback = [callback]
process = client.process(duration, node, proc_id)
self.process_dict[process.id] = process
- if async:
+ if asyn:
process.run_async()
else:
process.run()